import mysql.connector
import os
from dotenv import load_dotenv
import Logger
from sqlalchemy import create_engine
import pandas as pd


class Database:
    def __init__(self):
        load_dotenv()
        self.__db_host = os.getenv("db_host")
        self.__db_user = os.getenv("db_user")
        self.__db_pass = os.getenv("db_pass")
        self.__database = os.getenv("db")

    # Criar conexão (engine) com o DB
    def init_conn(self):
        log = Logger.Logger()
        try:
            engine = create_engine(f'mysql+mysqlconnector://{self.__db_user}:{self.__db_pass}'
                                   f'@{self.__db_host}/{self.__database}')
            return engine
        except mysql.connector.Error as err:
            log.error('db_error.log', err)

    # Inserir os dados no DB, utilizando o próprio DF e função 'to_sql' do Pandas.
    # Os dados são sobrescritos a cada execução.
    # Parâmetros: DataFrame e String (nome da tabela)
    def exec_insert(self, df, tabela):
        engine = self.init_conn()
        df.to_sql(tabela, con=engine, if_exists='replace', index=False)