import pandas as pd
import DB


class DataProcess:
    def __init__(self, sheet):
        self.__sheet = sheet

    # Cria os DataFrames (xlsx ou csv), filtrando dados não necessários e armazena em banco
    def process_sheet(self):
        pd.set_option('display.max_rows', None)
        if self.__sheet.endswith('.xlsx'):
            df = pd.read_excel(self.__sheet)
        else:
            df = pd.read_csv(self.__sheet)
        df = df.drop(columns=['Coluna1', 'Unnamed: 16', 'Unnamed: 17', 'Férias\n(Hoje)', 'Híbrido'])
        df['Matricula'] = df['Matricula'].replace('NaN', pd.NA).fillna(0).astype(int)
        df['E-mail'] = df['E-mail'].str.replace(';', '')

        df_supervisao = self.supervisao(df)
        df_equipe_suporte = self.equipe_suporte(df)
        db = DB.Database()
        db.exec_insert(df_equipe_suporte, 'agentes')
        db.exec_insert(df_supervisao, 'supervisores')

    # Seleciona apenas os supervisores do DataFrame completo (planilha suporte equipe compeleta)
    # Parâmetro: DataFrame
    @staticmethod
    def supervisao(df):
        df_supervisao = df.loc[df['Função'] == 'Supervisão']
        return df_supervisao

    # Seleciona apenas os agentes do DataFrame completo (planilha suporte equipe compeleta)
    # Parâmetro: DataFrame
    @staticmethod
    def equipe_suporte(df):
        df_equipe_suporte = df.loc[df['Função'] != 'Supervisão']
        df_equipe_suporte = df_equipe_suporte[df_equipe_suporte['Usuario'].notnull()]
        return df_equipe_suporte
