# coding: utf-8
import os
import Logger
from dotenv import load_dotenv
import email
import imaplib


class EmailReport:
    def __init__(self):
        load_dotenv()
        self.__email_acc = os.getenv("email_acc")
        self.__email_pw = os.getenv("email_pw")
        self.__imap_host = os.getenv("imap_host")
        self.__imap_port = os.getenv("imap_port")
        self.__sender = os.getenv("sender")
        # self.report_dir = r'/home/zengator/pranati/reports/'
        self.report_dir = r'planilhas'
        self.log = Logger.Logger()

    # Criar conexão com o mail server
    def imap_conn(self):
        try:
            conn = imaplib.IMAP4_SSL(self.__imap_host, self.__imap_port)
            conn.login(self.__email_acc, self.__email_pw)
            status, messages = conn.select('Inbox')
        except imaplib.IMAP4.abort as err:
            self.log.error('error.log', err)
            exit()
        return conn, status, messages

    # Deleta o email que foi lido
    def delete_mail(self, num, conn):
        try:
            conn.store(num, "+FLAGS", "\\Deleted")
        except Exception as err:
            self.log.error('error.log', err)
            exit()

    # Obtem o email e suas 'parts', para obter o anexo
    # Parâmetros: int (index/número da mensagem) e obj imaplib (conexão)
    def mail_check(self, num, conn):
        res, msg = conn.fetch(str(num), '(RFC822)')
        self.delete_mail(str(num), conn)
        try:
            for response in msg:
                if isinstance(response, tuple):
                    msg = email.message_from_bytes(response[1])
                    if msg.is_multipart():
                        for part in msg.walk():
                            content_type = part.get_content_type()
                            content_disposition = str(part.get('Content-Disposition'))
                            if 'attachment' in content_disposition:
                                report = part.get_filename()
                                if report:
                                    if not os.path.isdir(self.report_dir):
                                        os.mkdir(self.report_dir)
                                    filepath = os.path.join(self.report_dir, report)
                                    open(filepath, 'wb').write(part.get_payload(decode=True))
                                    return filepath
        except RuntimeError as err:
            self.log.error('error.log', err)

    # Busca por emails recebidos de um determinado remetente
    def get_support_sheet(self):
        conn, status, messages = self.imap_conn()
        try:
            status, messages = conn.search(None, f'(OR (FROM "{self.__sender}" ) (FROM "{self.__sender}"))')
            if messages[0]:
                print(f'num msgs: {int(messages[0].split()[-1])}')
                n = 1
                messages = int(messages[0].split()[-1])
                for num in range(messages, messages - n, -1):
                    # for num in range(1, messages+1):
                    file = self.mail_check(num, conn)
                conn.expunge()
                conn.close()
                conn.logout()
                return file
            else:
                exit()
        except RuntimeError as err:
            self.log.error('error.log', err)